==> release.12.0.73.1.tgz: prontus/cpan/js-local/common/helper.js <==
// Funciones generales de uso comun
// Utilidad para formateo de strings.
if (!String.prototype.format) {
    String.prototype.format = function() {
        var args = arguments;
        return this.replace(/{(\d+)}/g, function(match, number) {
        return typeof args[number] != 'undefined'? args[number]: match;
        });
    };
}

// Alertas, dialogos y confirmaciones. Modales.
function showModalConfirm (options) {
    if (typeof options == 'undefined') {
        return;
    }

    if (typeof $.confirm == 'undefined') {
        alert(options.msg);
        return;
    }

    if (typeof options.type == 'undefined') options.type = 'default';
    if (typeof options.title == 'undefined') options.title = "Confirmación";
    if (typeof options.btnClassOk == 'undefined') options.btnClassOk = 'hovwhite radius15 noborder txtnextwhite pad-top-bot7 pad-lef-rig20 int-nextgray4 nextgray4';
    if (typeof options.okTitle == 'undefined') options.okTitle = 'Continuar';
    if (typeof options.cancelTitle == 'undefined') options.cancelTitle = 'Cancelar';

    var html = $("#tpl_alert").html();
    var props = {
        template: html,
        useBootstrap: false,
        containerFluid: true,
        title: options.title,
        content: options.msg,
        type: options.type,
        escapeKey: 'cancel',
        closeIcon: false,
        scrollToPreviousElement: false,
        buttons: {
            ok: {
                text: options.okTitle,
                btnClass: options.btnClassOk,
                keys: ['enter'],
                action: function () {
                    if (typeof options.cbBtnOK != 'undefined') {
                        options.cbBtnOK();
                    }
                }
            },
            cancel: {
                text: options.cancelTitle,
                action: function () {
                    if (typeof options.cbBtnCancel != 'undefined') {
                        options.cbBtnCancel();
                    }
                }
            }
        }
    };

    props = $.extend(props, options);
    return $.confirm(props);
}

function showModalAlert (options) {
    if (typeof options == 'undefined') {
        return;
    }

    if (typeof $.alert == 'undefined') {
        alert(options.msg);
        return;
    }

    if (typeof options.type == 'undefined') options.type = 'default';
    if (typeof options.title == 'undefined') options.title = "Alerta";
    if (typeof options.btnClassOk == 'undefined') options.btnClassOk = 'hovwhite radius15 noborder txtnextwhite pad-top-bot7 pad-lef-rig20 int-nextgray4 nextgray4';
    if (typeof options.okTitle == 'undefined') options.okTitle = 'OK';

    var html = $("#tpl_alert").html();
    var props = {
        template: html,
        useBootstrap: false,
        title: options.title,
        content: options.msg,
        type: options.type,
        escapeKey: 'ok',
        closeIcon: false,
        scrollToPreviousElement: false,
        buttons: {
            ok: {
                text: options.okTitle,
                btnClass: options.btnClassOk,
                keys: ['enter'],
                action: function () {
                    if (typeof options.cbBtnOK != 'undefined') {
                        options.cbBtnOK();
                    }
                }
            }
        }
    };

    props = $.extend(props, options);
    return $.alert(props);
}

function showModalDialog (options) {
    if (typeof options == 'undefined') {
        return;
    }

    if (options.title == 'undefined') options.title = "Información";
    var html = $("#tpl_alert").html();
    var props = {
        template: html,
        useBootstrap: false,
        title: options.title,
        content: options.msg,
        type: options.type,
        closeIcon: false,
        escapeKey: false,
        scrollToPreviousElement: false
    };

    props = $.extend(props, options);
    return $.dialog(props);
}

  // Alertas de bootstrap. Requiere macro common/alertas.html.
function showSuccessAlert (addTo, msg, id) {
    $(addTo).find(".alert").remove();
    var html = $("#tpl_alert_success").html();

    if (html) {
        var $element = $();

        $element = $element.add(html);
        $element.attr("id", id);

        $element.find(".message").html(msg);
        $element.appendTo(addTo);
    }
}

function showInfoAlert (addTo, msg, id) {
    $(addTo).find(".alert").remove();
    var html = $("#tpl_alert_info").html();

    if (html) {
        var $element = $();
        $element = $element.add(html);
        $element.attr("id", id);

        $element.find(".message").html(msg);
        $element.appendTo(addTo);
    }
}

function showWarningAlert (addTo, msg, id) {
    $(addTo).find(".alert").remove();
    var html = $("#tpl_alert_warning").html();

    if (html) {
        var $element = $();
        $element = $element.add(html);
        $element.attr("id", id);

        $element.find(".message").html(msg);
        $element.appendTo(addTo);
    }
}

// Formateo de bytes a kb.
function bytesToKbytes (bytes) {
    bytes = bytes / 1024;

    if (bytes < 1) bytes = 1
    bytes = Math.round(bytes);;
    bytes = bytes.toLocaleString('es');

    return bytes + ' KiB';
}

function zeroLead(number) {
    return (number < 10 ? '0' +number: number);
}

==> release.12.3.1.2.tgz: prontus/cpan/js-local/common/helper.js <==
// Funciones generales de uso comun
// Utilidad para formateo de strings.
if (!String.prototype.format) {
    String.prototype.format = function() {
        var args = arguments;
        return this.replace(/{(\d+)}/g, function(match, number) {
        return typeof args[number] != 'undefined'? args[number]: match;
        });
    };
}

// Alertas, dialogos y confirmaciones. Modales.
function showModalConfirm (options) {
    if (typeof options == 'undefined') {
        return;
    }

    if (typeof $.confirm == 'undefined') {
        alert(options.msg);
        return;
    }

    if (typeof options.type == 'undefined') options.type = 'default';
    if (typeof options.title == 'undefined') options.title = ProntusL10n.get('global_confirm');
    if (typeof options.btnClassOk == 'undefined') options.btnClassOk = 'hovwhite radius15 noborder txtnextwhite pad-top-bot7 pad-lef-rig20 int-nextgray4 nextgray4';
    if (typeof options.okTitle == 'undefined') options.okTitle = ProntusL10n.get('global_continue_label');
    if (typeof options.cancelTitle == 'undefined') options.cancelTitle = ProntusL10n.get('global_cancel_label');

    var html = $("#tpl_alert").html();
    var props = {
        template: html,
        useBootstrap: false,
        containerFluid: true,
        title: options.title,
        content: options.msg,
        type: options.type,
        escapeKey: 'cancel',
        closeIcon: false,
        scrollToPreviousElement: false,
        buttons: {
            ok: {
                text: options.okTitle,
                btnClass: options.btnClassOk,
                keys: ['enter'],
                action: function () {
                    if (typeof options.cbBtnOK != 'undefined') {
                        options.cbBtnOK();
                    }
                }
            },
            cancel: {
                text: options.cancelTitle,
                action: function () {
                    if (typeof options.cbBtnCancel != 'undefined') {
                        options.cbBtnCancel();
                    }
                }
            }
        }
    };

    props = $.extend(props, options);
    return $.confirm(props);
}

function showModalAlert (options) {
    if (typeof options == 'undefined') {
        return;
    }

    if (typeof $.alert == 'undefined') {
        alert(options.msg);
        return;
    }

    if (typeof options.type == 'undefined') options.type = 'default';
    if (typeof options.title == 'undefined') options.title = ProntusL10n.get('global_alert');
    if (typeof options.btnClassOk == 'undefined') options.btnClassOk = 'hovwhite radius15 noborder txtnextwhite pad-top-bot7 pad-lef-rig20 int-nextgray4 nextgray4';
    if (typeof options.okTitle == 'undefined') options.okTitle = 'OK';

    var html = $("#tpl_alert").html();
    var props = {
        template: html,
        useBootstrap: false,
        title: options.title,
        content: options.msg,
        type: options.type,
        escapeKey: 'ok',
        closeIcon: false,
        scrollToPreviousElement: false,
        buttons: {
            ok: {
                text: options.okTitle,
                btnClass: options.btnClassOk,
                keys: ['enter'],
                action: function () {
                    if (typeof options.cbBtnOK != 'undefined') {
                        options.cbBtnOK();
                    }
                }
            }
        }
    };

    props = $.extend(props, options);
    return $.alert(props);
}

function showModalDialog (options) {
    if (typeof options == 'undefined') {
        return;
    }

    if (options.title == 'undefined') options.title = ProntusL10n.get('global_info_title');
    var html = $("#tpl_alert").html();
    var props = {
        template: html,
        useBootstrap: false,
        title: options.title,
        content: options.msg,
        type: options.type,
        closeIcon: false,
        escapeKey: false,
        scrollToPreviousElement: false
    };

    props = $.extend(props, options);
    return $.dialog(props);
}

  // Alertas de bootstrap. Requiere macro common/alertas.html.
function showSuccessAlert (addTo, msg, id) {
    $(addTo).find(".alert").remove();
    var html = $("#tpl_alert_success").html();

    if (html) {
        var $element = $();

        $element = $element.add(html);
        $element.attr("id", id);

        $element.find(".message").html(msg);
        $element.appendTo(addTo);
    }
}

function showInfoAlert (addTo, msg, id) {
    $(addTo).find(".alert").remove();
    var html = $("#tpl_alert_info").html();

    if (html) {
        var $element = $();
        $element = $element.add(html);
        $element.attr("id", id);

        $element.find(".message").html(msg);
        $element.appendTo(addTo);
    }
}

function showWarningAlert (addTo, msg, id) {
    $(addTo).find(".alert").remove();
    var html = $("#tpl_alert_warning").html();

    if (html) {
        var $element = $();
        $element = $element.add(html);
        $element.attr("id", id);

        $element.find(".message").html(msg);
        $element.appendTo(addTo);
    }
}

// Formateo de bytes a kb.
function bytesToKbytes (bytes) {
    bytes = bytes / 1024;

    if (bytes < 1) bytes = 1
    bytes = Math.round(bytes);
    bytes = bytes.toLocaleString('es');

    return bytes + ' KiB';
}

function zeroLead(number) {
    return (number < 10 ? '0' +number: number);
}
